# BulkTokenRevokeResponse

The response body of a bulk token revocation
## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**number_of_tokens_revoked** | **int** | The number of tokens that were revoked | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


